==> haskell-monad-control-1.0.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-control/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.0.5
id: monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
key: monad_0xW5zcMb0FUIevHTuIUHuL
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the @lifted-base@ package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-control-1.0.0.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-control-1.0.0.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-control-1.0.0.5
hs-libraries: HSmonad-control-1.0.0.5-0xW5zcMb0FUIevHTuIUHuL
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-control/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.1.0
id: monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
key: monad_DCjMscrbIXdFHUrAMwdfaD
license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the @lifted-base@ package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-control-1.0.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-control-1.0.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-control-1.0.1.0
hs-libraries: HSmonad-control-1.0.1.0-DCjMscrbIXdFHUrAMwdfaD
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
